binder

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 16, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Raw CGo bindings for Android Binder NDK

Index

Constants

const (
	EX_NONE                  = 0
	EX_SECURITY              = -1
	EX_BAD_PARCELABLE        = -2
	EX_ILLEGAL_ARGUMENT      = -3
	EX_NULL_POINTER          = -4
	EX_ILLEGAL_STATE         = -5
	EX_NETWORK_MAIN_THREAD   = -6
	EX_UNSUPPORTED_OPERATION = -7
	EX_SERVICE_SPECIFIC      = -8
	EX_PARCELABLE            = -9
	EX_TRANSACTION_FAILED    = -129
)
const (
	STATUS_OK                  = 0
	STATUS_UNKNOWN_ERROR       = -2147483648
	STATUS_NO_MEMORY           = -12
	STATUS_INVALID_OPERATION   = -38
	STATUS_BAD_VALUE           = -22
	STATUS_BAD_TYPE            = -2147483647
	STATUS_NAME_NOT_FOUND      = -2
	STATUS_PERMISSION_DENIED   = -1
	STATUS_NO_INIT             = -19
	STATUS_ALREADY_EXISTS      = -17
	STATUS_DEAD_OBJECT         = -32
	STATUS_FAILED_TRANSACTION  = -2147483646
	STATUS_BAD_INDEX           = -75
	STATUS_NOT_ENOUGH_DATA     = -61
	STATUS_WOULD_BLOCK         = -11
	STATUS_TIMED_OUT           = -110
	STATUS_UNKNOWN_TRANSACTION = -74
	STATUS_FDS_NOT_ALLOWED     = -2147483641
	STATUS_UNEXPECTED_NULL     = -2147483640
)
const (
	FLAG_ONEWAY = 1
)

Variables

This section is empty.

Functions

func AIBinder_Class_disableInterfaceTokenHeader

func AIBinder_Class_disableInterfaceTokenHeader(clazz *AIBinder_Class)

func AIBinder_Class_getDescriptor

func AIBinder_Class_getDescriptor(clazz *AIBinder_Class) string

func AIBinder_Class_onCreateAE3E288C

func AIBinder_Class_onCreateAE3E288C(cargs unsafe.Pointer) unsafe.Pointer

func AIBinder_Class_onDestroy2C719D10

func AIBinder_Class_onDestroy2C719D10(cuserData unsafe.Pointer)

func AIBinder_Class_onTransact4C5B3F35

func AIBinder_Class_onTransact4C5B3F35(cbinder *C.AIBinder, ccode C.transaction_code_t, cin *C.AParcel, cout *C.AParcel) C.binder_status_t

func AIBinder_Class_setOnDump

func AIBinder_Class_setOnDump(clazz *AIBinder_Class, onDump AIBinder_onDump)

func AIBinder_DeathRecipient_delete

func AIBinder_DeathRecipient_delete(recipient *AIBinder_DeathRecipient)

func AIBinder_DeathRecipient_onBinderDied7D6F4F1B

func AIBinder_DeathRecipient_onBinderDied7D6F4F1B()

func AIBinder_DeathRecipient_onBinderUnlinked6D499F91

func AIBinder_DeathRecipient_onBinderUnlinked6D499F91()

func AIBinder_DeathRecipient_setOnUnlinked

func AIBinder_DeathRecipient_setOnUnlinked(recipient *AIBinder_DeathRecipient, onUnlinked AIBinder_DeathRecipient_onBinderUnlinked)

func AIBinder_Weak_delete

func AIBinder_Weak_delete(weakBinder *AIBinder_Weak)

func AIBinder_Weak_lt

func AIBinder_Weak_lt(lhs *AIBinder_Weak, rhs *AIBinder_Weak) bool

func AIBinder_associateClass

func AIBinder_associateClass(binder *AIBinder, clazz *AIBinder_Class) bool

func AIBinder_debugGetRefCount

func AIBinder_debugGetRefCount(binder *AIBinder) int32

func AIBinder_decStrong

func AIBinder_decStrong(binder *AIBinder)

func AIBinder_getUserData

func AIBinder_getUserData(binder *AIBinder) unsafe.Pointer

func AIBinder_incStrong

func AIBinder_incStrong(binder *AIBinder)

func AIBinder_isAlive

func AIBinder_isAlive(binder *AIBinder) bool

func AIBinder_isHandlingTransaction

func AIBinder_isHandlingTransaction() bool

func AIBinder_isRemote

func AIBinder_isRemote(binder *AIBinder) bool

func AIBinder_lt

func AIBinder_lt(lhs *AIBinder, rhs *AIBinder) bool

func AIBinder_onDump04709357

func AIBinder_onDump04709357(cbinder *C.AIBinder, cfd C.int, cargs **C.int8_t, cnumArgs C.uint) C.binder_status_t

func AParcel_boolArrayAllocator6CE04D29

func AParcel_boolArrayAllocator6CE04D29(carrayData unsafe.Pointer, clength C.int) C._Bool

func AParcel_boolArrayGetter58F10D8E

func AParcel_boolArrayGetter58F10D8E(carrayData unsafe.Pointer, cindex C.uint64_t) C._Bool

func AParcel_boolArraySetterC31D06A6

func AParcel_boolArraySetterC31D06A6(carrayData unsafe.Pointer, cindex C.uint64_t, cvalue C._Bool)

func AParcel_byteArrayAllocator0F5D9BCB

func AParcel_byteArrayAllocator0F5D9BCB(carrayData unsafe.Pointer, clength C.int, coutBuffer **C.int8_t) C._Bool

func AParcel_charArrayAllocatorE28A23C0

func AParcel_charArrayAllocatorE28A23C0(carrayData unsafe.Pointer, clength C.int, coutBuffer **C.char16_t) C._Bool

func AParcel_delete

func AParcel_delete(parcel *AParcel)

func AParcel_doubleArrayAllocator0D8E072D

func AParcel_doubleArrayAllocator0D8E072D(carrayData unsafe.Pointer, clength C.int, coutBuffer **C.double) C._Bool

func AParcel_floatArrayAllocatorDDD314B6

func AParcel_floatArrayAllocatorDDD314B6(carrayData unsafe.Pointer, clength C.int, coutBuffer **C.float) C._Bool

func AParcel_getDataPosition

func AParcel_getDataPosition(parcel *AParcel) int32

func AParcel_getDataSize

func AParcel_getDataSize(parcel *AParcel) int32

func AParcel_int32ArrayAllocator632DB075

func AParcel_int32ArrayAllocator632DB075(carrayData unsafe.Pointer, clength C.int, coutBuffer **C.int) C._Bool

func AParcel_int64ArrayAllocatorE9CCD3BD

func AParcel_int64ArrayAllocatorE9CCD3BD(carrayData unsafe.Pointer, clength C.int, coutBuffer **C.int64_t) C._Bool

func AParcel_parcelableArrayAllocator6A96D230

func AParcel_parcelableArrayAllocator6A96D230(carrayData unsafe.Pointer, clength C.int) C._Bool

func AParcel_readParcelableElementF5964747

func AParcel_readParcelableElementF5964747(cparcel *C.AParcel, carrayData unsafe.Pointer, cindex C.uint64_t) C.binder_status_t

func AParcel_stringAllocatorFED8100A

func AParcel_stringAllocatorFED8100A(cstringData unsafe.Pointer, clength C.int, cbuffer **C.int8_t) C._Bool

func AParcel_stringArrayAllocatorA431F501

func AParcel_stringArrayAllocatorA431F501(carrayData unsafe.Pointer, clength C.int) C._Bool

func AParcel_stringArrayElementAllocator9AC166CA

func AParcel_stringArrayElementAllocator9AC166CA(carrayData unsafe.Pointer, cindex C.uint64_t, clength C.int, cbuffer **C.int8_t) C._Bool

func AParcel_stringArrayElementGetter6817B794

func AParcel_stringArrayElementGetter6817B794(carrayData unsafe.Pointer, cindex C.uint64_t, coutLength *C.int) *C.int8_t

func AParcel_uint32ArrayAllocatorDFFAD45C

func AParcel_uint32ArrayAllocatorDFFAD45C(carrayData unsafe.Pointer, clength C.int, coutBuffer **C.uint) C._Bool

func AParcel_uint64ArrayAllocatorCF52B274

func AParcel_uint64ArrayAllocatorCF52B274(carrayData unsafe.Pointer, clength C.int, coutBuffer **C.uint64_t) C._Bool

func AParcel_writeParcelableElement73CCA07C

func AParcel_writeParcelableElement73CCA07C(cparcel *C.AParcel, carrayData unsafe.Pointer, cindex C.uint64_t) C.binder_status_t

func AStatus_delete

func AStatus_delete(status *AStatus)

func AStatus_deleteDescription

func AStatus_deleteDescription(description string)

func AStatus_getDescription

func AStatus_getDescription(status *AStatus) string

func AStatus_getMessage

func AStatus_getMessage(status *AStatus) string

func AStatus_getServiceSpecificError

func AStatus_getServiceSpecificError(status *AStatus) int32

func AStatus_isOk

func AStatus_isOk(status *AStatus) bool

Types

type AIBinder

type AIBinder C.AIBinder

func AIBinder_Weak_promote

func AIBinder_Weak_promote(weakBinder *AIBinder_Weak) *AIBinder

func AIBinder_new

func AIBinder_new(clazz *AIBinder_Class, args unsafe.Pointer) *AIBinder

type AIBinder_Class

type AIBinder_Class C.AIBinder_Class

func AIBinder_Class_define

func AIBinder_Class_define(interfaceDescriptor string, onCreate AIBinder_Class_onCreate, onDestroy AIBinder_Class_onDestroy, onTransact AIBinder_Class_onTransact) *AIBinder_Class

func AIBinder_getClass

func AIBinder_getClass(binder *AIBinder) *AIBinder_Class

type AIBinder_Class_onCreate

type AIBinder_Class_onCreate func(args unsafe.Pointer) unsafe.Pointer

func NewAIBinder_Class_onCreateRef

func NewAIBinder_Class_onCreateRef(ref unsafe.Pointer) *AIBinder_Class_onCreate

func (AIBinder_Class_onCreate) PassRef

func (x AIBinder_Class_onCreate) PassRef() (ref *C.AIBinder_Class_onCreate, allocs *CgoAllocMap)

func (AIBinder_Class_onCreate) PassValue

func (x AIBinder_Class_onCreate) PassValue() (ref C.AIBinder_Class_onCreate, allocs *CgoAllocMap)

type AIBinder_Class_onDestroy

type AIBinder_Class_onDestroy func(userData unsafe.Pointer)

func NewAIBinder_Class_onDestroyRef

func NewAIBinder_Class_onDestroyRef(ref unsafe.Pointer) *AIBinder_Class_onDestroy

func (AIBinder_Class_onDestroy) PassRef

func (x AIBinder_Class_onDestroy) PassRef() (ref *C.AIBinder_Class_onDestroy, allocs *CgoAllocMap)

func (AIBinder_Class_onDestroy) PassValue

func (x AIBinder_Class_onDestroy) PassValue() (ref C.AIBinder_Class_onDestroy, allocs *CgoAllocMap)

type AIBinder_Class_onTransact

type AIBinder_Class_onTransact func(binder *AIBinder, code Transaction_code_t, in *AParcel, out *AParcel) Binder_status_t

func NewAIBinder_Class_onTransactRef

func NewAIBinder_Class_onTransactRef(ref unsafe.Pointer) *AIBinder_Class_onTransact

func (AIBinder_Class_onTransact) PassRef

func (AIBinder_Class_onTransact) PassValue

type AIBinder_DeathRecipient

type AIBinder_DeathRecipient C.AIBinder_DeathRecipient

type AIBinder_DeathRecipient_onBinderDied

type AIBinder_DeathRecipient_onBinderDied func()

func NewAIBinder_DeathRecipient_onBinderDiedRef

func NewAIBinder_DeathRecipient_onBinderDiedRef(ref unsafe.Pointer) *AIBinder_DeathRecipient_onBinderDied

func (AIBinder_DeathRecipient_onBinderDied) PassRef

func (AIBinder_DeathRecipient_onBinderDied) PassValue

type AIBinder_DeathRecipient_onBinderUnlinked

type AIBinder_DeathRecipient_onBinderUnlinked func()

func NewAIBinder_DeathRecipient_onBinderUnlinkedRef

func NewAIBinder_DeathRecipient_onBinderUnlinkedRef(ref unsafe.Pointer) *AIBinder_DeathRecipient_onBinderUnlinked

func (AIBinder_DeathRecipient_onBinderUnlinked) PassRef

func (AIBinder_DeathRecipient_onBinderUnlinked) PassValue

type AIBinder_Weak

type AIBinder_Weak C.AIBinder_Weak

func AIBinder_Weak_clone

func AIBinder_Weak_clone(weak *AIBinder_Weak) *AIBinder_Weak

func AIBinder_Weak_new

func AIBinder_Weak_new(binder *AIBinder) *AIBinder_Weak

type AIBinder_onDump

type AIBinder_onDump func(binder *AIBinder, fd int32, args **int8, numArgs uint32) Binder_status_t

func NewAIBinder_onDumpRef

func NewAIBinder_onDumpRef(ref unsafe.Pointer) *AIBinder_onDump

func (AIBinder_onDump) PassRef

func (x AIBinder_onDump) PassRef() (ref *C.AIBinder_onDump, allocs *CgoAllocMap)

func (AIBinder_onDump) PassValue

func (x AIBinder_onDump) PassValue() (ref C.AIBinder_onDump, allocs *CgoAllocMap)

type AParcel

type AParcel C.AParcel

func AParcel_create

func AParcel_create() *AParcel

type AParcel_boolArrayAllocator

type AParcel_boolArrayAllocator func(arrayData unsafe.Pointer, length int32) bool

func NewAParcel_boolArrayAllocatorRef

func NewAParcel_boolArrayAllocatorRef(ref unsafe.Pointer) *AParcel_boolArrayAllocator

func (AParcel_boolArrayAllocator) PassRef

func (AParcel_boolArrayAllocator) PassValue

type AParcel_boolArrayGetter

type AParcel_boolArrayGetter func(arrayData unsafe.Pointer, index uint64) bool

func NewAParcel_boolArrayGetterRef

func NewAParcel_boolArrayGetterRef(ref unsafe.Pointer) *AParcel_boolArrayGetter

func (AParcel_boolArrayGetter) PassRef

func (x AParcel_boolArrayGetter) PassRef() (ref *C.AParcel_boolArrayGetter, allocs *CgoAllocMap)

func (AParcel_boolArrayGetter) PassValue

func (x AParcel_boolArrayGetter) PassValue() (ref C.AParcel_boolArrayGetter, allocs *CgoAllocMap)

type AParcel_boolArraySetter

type AParcel_boolArraySetter func(arrayData unsafe.Pointer, index uint64, value bool)

func NewAParcel_boolArraySetterRef

func NewAParcel_boolArraySetterRef(ref unsafe.Pointer) *AParcel_boolArraySetter

func (AParcel_boolArraySetter) PassRef

func (x AParcel_boolArraySetter) PassRef() (ref *C.AParcel_boolArraySetter, allocs *CgoAllocMap)

func (AParcel_boolArraySetter) PassValue

func (x AParcel_boolArraySetter) PassValue() (ref C.AParcel_boolArraySetter, allocs *CgoAllocMap)

type AParcel_byteArrayAllocator

type AParcel_byteArrayAllocator func(arrayData unsafe.Pointer, length int32, outBuffer **int8) bool

func NewAParcel_byteArrayAllocatorRef

func NewAParcel_byteArrayAllocatorRef(ref unsafe.Pointer) *AParcel_byteArrayAllocator

func (AParcel_byteArrayAllocator) PassRef

func (AParcel_byteArrayAllocator) PassValue

type AParcel_charArrayAllocator

type AParcel_charArrayAllocator func(arrayData unsafe.Pointer, length int32, outBuffer **Char16_t) bool

func NewAParcel_charArrayAllocatorRef

func NewAParcel_charArrayAllocatorRef(ref unsafe.Pointer) *AParcel_charArrayAllocator

func (AParcel_charArrayAllocator) PassRef

func (AParcel_charArrayAllocator) PassValue

type AParcel_doubleArrayAllocator

type AParcel_doubleArrayAllocator func(arrayData unsafe.Pointer, length int32, outBuffer **float64) bool

func NewAParcel_doubleArrayAllocatorRef

func NewAParcel_doubleArrayAllocatorRef(ref unsafe.Pointer) *AParcel_doubleArrayAllocator

func (AParcel_doubleArrayAllocator) PassRef

func (AParcel_doubleArrayAllocator) PassValue

type AParcel_floatArrayAllocator

type AParcel_floatArrayAllocator func(arrayData unsafe.Pointer, length int32, outBuffer **float32) bool

func NewAParcel_floatArrayAllocatorRef

func NewAParcel_floatArrayAllocatorRef(ref unsafe.Pointer) *AParcel_floatArrayAllocator

func (AParcel_floatArrayAllocator) PassRef

func (AParcel_floatArrayAllocator) PassValue

type AParcel_int32ArrayAllocator

type AParcel_int32ArrayAllocator func(arrayData unsafe.Pointer, length int32, outBuffer **int32) bool

func NewAParcel_int32ArrayAllocatorRef

func NewAParcel_int32ArrayAllocatorRef(ref unsafe.Pointer) *AParcel_int32ArrayAllocator

func (AParcel_int32ArrayAllocator) PassRef

func (AParcel_int32ArrayAllocator) PassValue

type AParcel_int64ArrayAllocator

type AParcel_int64ArrayAllocator func(arrayData unsafe.Pointer, length int32, outBuffer **int64) bool

func NewAParcel_int64ArrayAllocatorRef

func NewAParcel_int64ArrayAllocatorRef(ref unsafe.Pointer) *AParcel_int64ArrayAllocator

func (AParcel_int64ArrayAllocator) PassRef

func (AParcel_int64ArrayAllocator) PassValue

type AParcel_parcelableArrayAllocator

type AParcel_parcelableArrayAllocator func(arrayData unsafe.Pointer, length int32) bool

func NewAParcel_parcelableArrayAllocatorRef

func NewAParcel_parcelableArrayAllocatorRef(ref unsafe.Pointer) *AParcel_parcelableArrayAllocator

func (AParcel_parcelableArrayAllocator) PassRef

func (AParcel_parcelableArrayAllocator) PassValue

type AParcel_readParcelableElement

type AParcel_readParcelableElement func(parcel *AParcel, arrayData unsafe.Pointer, index uint64) Binder_status_t

func NewAParcel_readParcelableElementRef

func NewAParcel_readParcelableElementRef(ref unsafe.Pointer) *AParcel_readParcelableElement

func (AParcel_readParcelableElement) PassRef

func (AParcel_readParcelableElement) PassValue

type AParcel_stringAllocator

type AParcel_stringAllocator func(stringData unsafe.Pointer, length int32, buffer **int8) bool

func NewAParcel_stringAllocatorRef

func NewAParcel_stringAllocatorRef(ref unsafe.Pointer) *AParcel_stringAllocator

func (AParcel_stringAllocator) PassRef

func (x AParcel_stringAllocator) PassRef() (ref *C.AParcel_stringAllocator, allocs *CgoAllocMap)

func (AParcel_stringAllocator) PassValue

func (x AParcel_stringAllocator) PassValue() (ref C.AParcel_stringAllocator, allocs *CgoAllocMap)

type AParcel_stringArrayAllocator

type AParcel_stringArrayAllocator func(arrayData unsafe.Pointer, length int32) bool

func NewAParcel_stringArrayAllocatorRef

func NewAParcel_stringArrayAllocatorRef(ref unsafe.Pointer) *AParcel_stringArrayAllocator

func (AParcel_stringArrayAllocator) PassRef

func (AParcel_stringArrayAllocator) PassValue

type AParcel_stringArrayElementAllocator

type AParcel_stringArrayElementAllocator func(arrayData unsafe.Pointer, index uint64, length int32, buffer **int8) bool

func NewAParcel_stringArrayElementAllocatorRef

func NewAParcel_stringArrayElementAllocatorRef(ref unsafe.Pointer) *AParcel_stringArrayElementAllocator

func (AParcel_stringArrayElementAllocator) PassRef

func (AParcel_stringArrayElementAllocator) PassValue

type AParcel_stringArrayElementGetter

type AParcel_stringArrayElementGetter func(arrayData unsafe.Pointer, index uint64, outLength *int32) *int8

func NewAParcel_stringArrayElementGetterRef

func NewAParcel_stringArrayElementGetterRef(ref unsafe.Pointer) *AParcel_stringArrayElementGetter

func (AParcel_stringArrayElementGetter) PassRef

func (AParcel_stringArrayElementGetter) PassValue

type AParcel_uint32ArrayAllocator

type AParcel_uint32ArrayAllocator func(arrayData unsafe.Pointer, length int32, outBuffer **uint32) bool

func NewAParcel_uint32ArrayAllocatorRef

func NewAParcel_uint32ArrayAllocatorRef(ref unsafe.Pointer) *AParcel_uint32ArrayAllocator

func (AParcel_uint32ArrayAllocator) PassRef

func (AParcel_uint32ArrayAllocator) PassValue

type AParcel_uint64ArrayAllocator

type AParcel_uint64ArrayAllocator func(arrayData unsafe.Pointer, length int32, outBuffer **uint64) bool

func NewAParcel_uint64ArrayAllocatorRef

func NewAParcel_uint64ArrayAllocatorRef(ref unsafe.Pointer) *AParcel_uint64ArrayAllocator

func (AParcel_uint64ArrayAllocator) PassRef

func (AParcel_uint64ArrayAllocator) PassValue

type AParcel_writeParcelableElement

type AParcel_writeParcelableElement func(parcel *AParcel, arrayData unsafe.Pointer, index uint64) Binder_status_t

func NewAParcel_writeParcelableElementRef

func NewAParcel_writeParcelableElementRef(ref unsafe.Pointer) *AParcel_writeParcelableElement

func (AParcel_writeParcelableElement) PassRef

func (AParcel_writeParcelableElement) PassValue

type AStatus

type AStatus C.AStatus

func AStatus_fromExceptionCode

func AStatus_fromExceptionCode(exception Binder_exception_t) *AStatus

func AStatus_fromExceptionCodeWithMessage

func AStatus_fromExceptionCodeWithMessage(exception Binder_exception_t, message string) *AStatus

func AStatus_fromServiceSpecificError

func AStatus_fromServiceSpecificError(serviceSpecific int32) *AStatus

func AStatus_fromServiceSpecificErrorWithMessage

func AStatus_fromServiceSpecificErrorWithMessage(serviceSpecific int32, message string) *AStatus

func AStatus_fromStatus

func AStatus_fromStatus(status Binder_status_t) *AStatus

func AStatus_newOk

func AStatus_newOk() *AStatus

type Binder_exception_t

type Binder_exception_t int32

func AStatus_getExceptionCode

func AStatus_getExceptionCode(status *AStatus) Binder_exception_t

type Binder_flags_t

type Binder_flags_t uint32

type Binder_status_t

type Binder_status_t int32

func AIBinder_dump

func AIBinder_dump(binder *AIBinder, fd int32, args *string, numArgs uint32) Binder_status_t

func AIBinder_getExtension

func AIBinder_getExtension(binder *AIBinder, outExt **AIBinder) Binder_status_t

func AIBinder_linkToDeath

func AIBinder_linkToDeath(binder *AIBinder, recipient *AIBinder_DeathRecipient, cookie unsafe.Pointer) Binder_status_t

func AIBinder_ping

func AIBinder_ping(binder *AIBinder) Binder_status_t

func AIBinder_prepareTransaction

func AIBinder_prepareTransaction(binder *AIBinder, in **AParcel) Binder_status_t

func AIBinder_setExtension

func AIBinder_setExtension(binder *AIBinder, ext *AIBinder) Binder_status_t

func AIBinder_transact

func AIBinder_transact(binder *AIBinder, code Transaction_code_t, in **AParcel, out **AParcel, flags Binder_flags_t) Binder_status_t

func AIBinder_unlinkToDeath

func AIBinder_unlinkToDeath(binder *AIBinder, recipient *AIBinder_DeathRecipient, cookie unsafe.Pointer) Binder_status_t

func AParcel_appendFrom

func AParcel_appendFrom(from *AParcel, to *AParcel, start int32, size int32) Binder_status_t

func AParcel_marshal

func AParcel_marshal(parcel *AParcel, buffer *uint8, start uint64, len uint64) Binder_status_t

func AParcel_readBool

func AParcel_readBool(parcel *AParcel, value *bool) Binder_status_t

func AParcel_readBoolArray

func AParcel_readBoolArray(parcel *AParcel, arrayData unsafe.Pointer, allocator AParcel_boolArrayAllocator, setter AParcel_boolArraySetter) Binder_status_t

func AParcel_readByte

func AParcel_readByte(parcel *AParcel, value *int8) Binder_status_t

func AParcel_readByteArray

func AParcel_readByteArray(parcel *AParcel, arrayData unsafe.Pointer, allocator AParcel_byteArrayAllocator) Binder_status_t

func AParcel_readChar

func AParcel_readChar(parcel *AParcel, value *Char16_t) Binder_status_t

func AParcel_readCharArray

func AParcel_readCharArray(parcel *AParcel, arrayData unsafe.Pointer, allocator AParcel_charArrayAllocator) Binder_status_t

func AParcel_readDouble

func AParcel_readDouble(parcel *AParcel, value *float64) Binder_status_t

func AParcel_readDoubleArray

func AParcel_readDoubleArray(parcel *AParcel, arrayData unsafe.Pointer, allocator AParcel_doubleArrayAllocator) Binder_status_t

func AParcel_readFloat

func AParcel_readFloat(parcel *AParcel, value *float32) Binder_status_t

func AParcel_readFloatArray

func AParcel_readFloatArray(parcel *AParcel, arrayData unsafe.Pointer, allocator AParcel_floatArrayAllocator) Binder_status_t

func AParcel_readInt32

func AParcel_readInt32(parcel *AParcel, value *int32) Binder_status_t

func AParcel_readInt32Array

func AParcel_readInt32Array(parcel *AParcel, arrayData unsafe.Pointer, allocator AParcel_int32ArrayAllocator) Binder_status_t

func AParcel_readInt64

func AParcel_readInt64(parcel *AParcel, value *int64) Binder_status_t

func AParcel_readInt64Array

func AParcel_readInt64Array(parcel *AParcel, arrayData unsafe.Pointer, allocator AParcel_int64ArrayAllocator) Binder_status_t

func AParcel_readParcelFileDescriptor

func AParcel_readParcelFileDescriptor(parcel *AParcel, fd *int32) Binder_status_t

func AParcel_readParcelableArray

func AParcel_readParcelableArray(parcel *AParcel, arrayData unsafe.Pointer, allocator AParcel_parcelableArrayAllocator, elementReader AParcel_readParcelableElement) Binder_status_t

func AParcel_readStatusHeader

func AParcel_readStatusHeader(parcel *AParcel, status **AStatus) Binder_status_t

func AParcel_readString

func AParcel_readString(parcel *AParcel, stringData unsafe.Pointer, allocator AParcel_stringAllocator) Binder_status_t

func AParcel_readStringArray

func AParcel_readStringArray(parcel *AParcel, arrayData unsafe.Pointer, allocator AParcel_stringArrayAllocator, elementAllocator AParcel_stringArrayElementAllocator) Binder_status_t

func AParcel_readStrongBinder

func AParcel_readStrongBinder(parcel *AParcel, binder **AIBinder) Binder_status_t

func AParcel_readUint32

func AParcel_readUint32(parcel *AParcel, value *uint32) Binder_status_t

func AParcel_readUint32Array

func AParcel_readUint32Array(parcel *AParcel, arrayData unsafe.Pointer, allocator AParcel_uint32ArrayAllocator) Binder_status_t

func AParcel_readUint64

func AParcel_readUint64(parcel *AParcel, value *uint64) Binder_status_t

func AParcel_readUint64Array

func AParcel_readUint64Array(parcel *AParcel, arrayData unsafe.Pointer, allocator AParcel_uint64ArrayAllocator) Binder_status_t

func AParcel_reset

func AParcel_reset(parcel *AParcel) Binder_status_t

func AParcel_setDataPosition

func AParcel_setDataPosition(parcel *AParcel, position int32) Binder_status_t

func AParcel_unmarshal

func AParcel_unmarshal(parcel *AParcel, buffer *uint8, len uint64) Binder_status_t

func AParcel_writeBool

func AParcel_writeBool(parcel *AParcel, value bool) Binder_status_t

func AParcel_writeBoolArray

func AParcel_writeBoolArray(parcel *AParcel, arrayData unsafe.Pointer, length int32, getter AParcel_boolArrayGetter) Binder_status_t

func AParcel_writeByte

func AParcel_writeByte(parcel *AParcel, value int8) Binder_status_t

func AParcel_writeByteArray

func AParcel_writeByteArray(parcel *AParcel, arrayData *int8, length int32) Binder_status_t

func AParcel_writeChar

func AParcel_writeChar(parcel *AParcel, value Char16_t) Binder_status_t

func AParcel_writeCharArray

func AParcel_writeCharArray(parcel *AParcel, arrayData *Char16_t, length int32) Binder_status_t

func AParcel_writeDouble

func AParcel_writeDouble(parcel *AParcel, value float64) Binder_status_t

func AParcel_writeDoubleArray

func AParcel_writeDoubleArray(parcel *AParcel, arrayData *float64, length int32) Binder_status_t

func AParcel_writeFloat

func AParcel_writeFloat(parcel *AParcel, value float32) Binder_status_t

func AParcel_writeFloatArray

func AParcel_writeFloatArray(parcel *AParcel, arrayData *float32, length int32) Binder_status_t

func AParcel_writeInt32

func AParcel_writeInt32(parcel *AParcel, value int32) Binder_status_t

func AParcel_writeInt32Array

func AParcel_writeInt32Array(parcel *AParcel, arrayData *int32, length int32) Binder_status_t

func AParcel_writeInt64

func AParcel_writeInt64(parcel *AParcel, value int64) Binder_status_t

func AParcel_writeInt64Array

func AParcel_writeInt64Array(parcel *AParcel, arrayData *int64, length int32) Binder_status_t

func AParcel_writeParcelFileDescriptor

func AParcel_writeParcelFileDescriptor(parcel *AParcel, fd int32) Binder_status_t

func AParcel_writeParcelableArray

func AParcel_writeParcelableArray(parcel *AParcel, arrayData unsafe.Pointer, length int32, elementWriter AParcel_writeParcelableElement) Binder_status_t

func AParcel_writeStatusHeader

func AParcel_writeStatusHeader(parcel *AParcel, status *AStatus) Binder_status_t

func AParcel_writeString

func AParcel_writeString(parcel *AParcel, _string string, length int32) Binder_status_t

func AParcel_writeStringArray

func AParcel_writeStringArray(parcel *AParcel, arrayData unsafe.Pointer, length int32, getter AParcel_stringArrayElementGetter) Binder_status_t

func AParcel_writeStrongBinder

func AParcel_writeStrongBinder(parcel *AParcel, binder *AIBinder) Binder_status_t

func AParcel_writeUint32

func AParcel_writeUint32(parcel *AParcel, value uint32) Binder_status_t

func AParcel_writeUint32Array

func AParcel_writeUint32Array(parcel *AParcel, arrayData *uint32, length int32) Binder_status_t

func AParcel_writeUint64

func AParcel_writeUint64(parcel *AParcel, value uint64) Binder_status_t

func AParcel_writeUint64Array

func AParcel_writeUint64Array(parcel *AParcel, arrayData *uint64, length int32) Binder_status_t

func AStatus_getStatus

func AStatus_getStatus(status *AStatus) Binder_status_t

type CgoAllocMap

type CgoAllocMap struct {
	// contains filtered or unexported fields
}

CgoAllocMap stores pointers to C allocated memory for future reference.

func UnpackPCharString

func UnpackPCharString(str string) (*C.char, *CgoAllocMap)

UnpackPCharString copies the data from Go string as *C.char.

func (*CgoAllocMap) Add

func (a *CgoAllocMap) Add(ptr unsafe.Pointer)

func (*CgoAllocMap) Borrow

func (a *CgoAllocMap) Borrow(b *CgoAllocMap)

func (*CgoAllocMap) Free

func (a *CgoAllocMap) Free()

func (*CgoAllocMap) IsEmpty

func (a *CgoAllocMap) IsEmpty() bool

type Char16_t

type Char16_t C.char16_t

type Pid_t

type Pid_t C.pid_t

func AIBinder_getCallingPid

func AIBinder_getCallingPid() Pid_t

type SliceHeader

type SliceHeader struct {
	Data unsafe.Pointer
	Len  int
	Cap  int
}

type Transaction_code_t

type Transaction_code_t uint32

type Uid_t

type Uid_t C.uid_t

func AIBinder_getCallingUid

func AIBinder_getCallingUid() Uid_t

Jump to