persistablebundle

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 16, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Raw CGo bindings for Android PersistableBundle NDK

Index

Constants

const (
	APERSISTABLEBUNDLE_KEY_NOT_FOUND    = -1
	APERSISTABLEBUNDLE_ALLOCATOR_FAILED = -2
)

Variables

This section is empty.

Functions

func APersistableBundle_delete

func APersistableBundle_delete(pBundle *APersistableBundle)

func APersistableBundle_erase

func APersistableBundle_erase(pBundle *APersistableBundle, key string) int32

func APersistableBundle_getBoolean

func APersistableBundle_getBoolean(pBundle *APersistableBundle, key string, val *bool) bool

func APersistableBundle_getBooleanKeys

func APersistableBundle_getBooleanKeys(pBundle *APersistableBundle, outKeys *string, bufferSizeBytes int32, stringAllocator APersistableBundle_stringAllocator, context unsafe.Pointer) int32

func APersistableBundle_getBooleanVector

func APersistableBundle_getBooleanVector(pBundle *APersistableBundle, key string, buffer *bool, bufferSizeBytes int32) int32

func APersistableBundle_getBooleanVectorKeys

func APersistableBundle_getBooleanVectorKeys(pBundle *APersistableBundle, outKeys *string, bufferSizeBytes int32, stringAllocator APersistableBundle_stringAllocator, context unsafe.Pointer) int32

func APersistableBundle_getDouble

func APersistableBundle_getDouble(pBundle *APersistableBundle, key string, val *float64) bool

func APersistableBundle_getDoubleKeys

func APersistableBundle_getDoubleKeys(pBundle *APersistableBundle, outKeys *string, bufferSizeBytes int32, stringAllocator APersistableBundle_stringAllocator, context unsafe.Pointer) int32

func APersistableBundle_getDoubleVector

func APersistableBundle_getDoubleVector(pBundle *APersistableBundle, key string, buffer *float64, bufferSizeBytes int32) int32

func APersistableBundle_getDoubleVectorKeys

func APersistableBundle_getDoubleVectorKeys(pBundle *APersistableBundle, outKeys *string, bufferSizeBytes int32, stringAllocator APersistableBundle_stringAllocator, context unsafe.Pointer) int32

func APersistableBundle_getInt

func APersistableBundle_getInt(pBundle *APersistableBundle, key string, val *int32) bool

func APersistableBundle_getIntKeys

func APersistableBundle_getIntKeys(pBundle *APersistableBundle, outKeys *string, bufferSizeBytes int32, stringAllocator APersistableBundle_stringAllocator, context unsafe.Pointer) int32

func APersistableBundle_getIntVector

func APersistableBundle_getIntVector(pBundle *APersistableBundle, key string, buffer *int32, bufferSizeBytes int32) int32

func APersistableBundle_getIntVectorKeys

func APersistableBundle_getIntVectorKeys(pBundle *APersistableBundle, outKeys *string, bufferSizeBytes int32, stringAllocator APersistableBundle_stringAllocator, context unsafe.Pointer) int32

func APersistableBundle_getLong

func APersistableBundle_getLong(pBundle *APersistableBundle, key string, val *int64) bool

func APersistableBundle_getLongKeys

func APersistableBundle_getLongKeys(pBundle *APersistableBundle, outKeys *string, bufferSizeBytes int32, stringAllocator APersistableBundle_stringAllocator, context unsafe.Pointer) int32

func APersistableBundle_getLongVector

func APersistableBundle_getLongVector(pBundle *APersistableBundle, key string, buffer *int64, bufferSizeBytes int32) int32

func APersistableBundle_getLongVectorKeys

func APersistableBundle_getLongVectorKeys(pBundle *APersistableBundle, outKeys *string, bufferSizeBytes int32, stringAllocator APersistableBundle_stringAllocator, context unsafe.Pointer) int32

func APersistableBundle_getPersistableBundle

func APersistableBundle_getPersistableBundle(pBundle *APersistableBundle, key string, outBundle **APersistableBundle) bool

func APersistableBundle_getPersistableBundleKeys

func APersistableBundle_getPersistableBundleKeys(pBundle *APersistableBundle, outKeys *string, bufferSizeBytes int32, stringAllocator APersistableBundle_stringAllocator, context unsafe.Pointer) int32

func APersistableBundle_getString

func APersistableBundle_getString(pBundle *APersistableBundle, key string, val *string, stringAllocator APersistableBundle_stringAllocator, context unsafe.Pointer) int32

func APersistableBundle_getStringKeys

func APersistableBundle_getStringKeys(pBundle *APersistableBundle, outKeys *string, bufferSizeBytes int32, stringAllocator APersistableBundle_stringAllocator, context unsafe.Pointer) int32

func APersistableBundle_getStringVector

func APersistableBundle_getStringVector(pBundle *APersistableBundle, key string, buffer *string, bufferSizeBytes int32, stringAllocator APersistableBundle_stringAllocator, context unsafe.Pointer) int32

func APersistableBundle_getStringVectorKeys

func APersistableBundle_getStringVectorKeys(pBundle *APersistableBundle, outKeys *string, bufferSizeBytes int32, stringAllocator APersistableBundle_stringAllocator, context unsafe.Pointer) int32

func APersistableBundle_isEqual

func APersistableBundle_isEqual(lhs *APersistableBundle, rhs *APersistableBundle) bool

func APersistableBundle_putBoolean

func APersistableBundle_putBoolean(pBundle *APersistableBundle, key string, val bool)

func APersistableBundle_putBooleanVector

func APersistableBundle_putBooleanVector(pBundle *APersistableBundle, key string, vec *bool, num int32)

func APersistableBundle_putDouble

func APersistableBundle_putDouble(pBundle *APersistableBundle, key string, val float64)

func APersistableBundle_putDoubleVector

func APersistableBundle_putDoubleVector(pBundle *APersistableBundle, key string, vec *float64, num int32)

func APersistableBundle_putInt

func APersistableBundle_putInt(pBundle *APersistableBundle, key string, val int32)

func APersistableBundle_putIntVector

func APersistableBundle_putIntVector(pBundle *APersistableBundle, key string, vec *int32, num int32)

func APersistableBundle_putLong

func APersistableBundle_putLong(pBundle *APersistableBundle, key string, val int64)

func APersistableBundle_putLongVector

func APersistableBundle_putLongVector(pBundle *APersistableBundle, key string, vec *int64, num int32)

func APersistableBundle_putPersistableBundle

func APersistableBundle_putPersistableBundle(pBundle *APersistableBundle, key string, val *APersistableBundle)

func APersistableBundle_putString

func APersistableBundle_putString(pBundle *APersistableBundle, key string, val string)

func APersistableBundle_putStringVector

func APersistableBundle_putStringVector(pBundle *APersistableBundle, key string, vec *string, num int32)

func APersistableBundle_size

func APersistableBundle_size(pBundle *APersistableBundle) int32

func APersistableBundle_stringAllocatorD22E9A69

func APersistableBundle_stringAllocatorD22E9A69()

Types

type AParcel

type AParcel C.AParcel

type APersistableBundle

type APersistableBundle C.APersistableBundle

func APersistableBundle_dup

func APersistableBundle_dup(pBundle *APersistableBundle) *APersistableBundle

func APersistableBundle_new

func APersistableBundle_new() *APersistableBundle

type APersistableBundle_stringAllocator

type APersistableBundle_stringAllocator func()

func NewAPersistableBundle_stringAllocatorRef

func NewAPersistableBundle_stringAllocatorRef(ref unsafe.Pointer) *APersistableBundle_stringAllocator

func (APersistableBundle_stringAllocator) PassRef

func (APersistableBundle_stringAllocator) PassValue

type Binder_status_t

type Binder_status_t C.binder_status_t

func APersistableBundle_readFromParcel

func APersistableBundle_readFromParcel(parcel *AParcel, outPBundle **APersistableBundle) Binder_status_t

func APersistableBundle_writeToParcel

func APersistableBundle_writeToParcel(pBundle *APersistableBundle, parcel *AParcel) Binder_status_t

type CgoAllocMap

type CgoAllocMap struct {
	// contains filtered or unexported fields
}

CgoAllocMap stores pointers to C allocated memory for future reference.

func UnpackPCharString

func UnpackPCharString(str string) (*C.char, *CgoAllocMap)

UnpackPCharString copies the data from Go string as *C.char.

func (*CgoAllocMap) Add

func (a *CgoAllocMap) Add(ptr unsafe.Pointer)

func (*CgoAllocMap) Borrow

func (a *CgoAllocMap) Borrow(b *CgoAllocMap)

func (*CgoAllocMap) Free

func (a *CgoAllocMap) Free()

func (*CgoAllocMap) IsEmpty

func (a *CgoAllocMap) IsEmpty() bool

type SliceHeader

type SliceHeader struct {
	Data unsafe.Pointer
	Len  int
	Cap  int
}

Jump to