trace

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 16, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Raw CGo bindings for Android trace

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ATrace_beginAsyncSection

func ATrace_beginAsyncSection(sectionName string, cookie int32)

func ATrace_beginSection

func ATrace_beginSection(sectionName string)

func ATrace_endAsyncSection

func ATrace_endAsyncSection(sectionName string, cookie int32)

func ATrace_endSection

func ATrace_endSection()

func ATrace_isEnabled

func ATrace_isEnabled() bool

func ATrace_setCounter

func ATrace_setCounter(counterName string, counterValue int64)

Types

type CgoAllocMap

type CgoAllocMap struct {
	// contains filtered or unexported fields
}

CgoAllocMap stores pointers to C allocated memory for future reference.

func UnpackPCharString

func UnpackPCharString(str string) (*C.char, *CgoAllocMap)

UnpackPCharString copies the data from Go string as *C.char.

func (*CgoAllocMap) Add

func (a *CgoAllocMap) Add(ptr unsafe.Pointer)

func (*CgoAllocMap) Borrow

func (a *CgoAllocMap) Borrow(b *CgoAllocMap)

func (*CgoAllocMap) Free

func (a *CgoAllocMap) Free()

func (*CgoAllocMap) IsEmpty

func (a *CgoAllocMap) IsEmpty() bool

type SliceHeader

type SliceHeader struct {
	Data unsafe.Pointer
	Len  int
	Cap  int
}

Jump to