choreographer

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package choreographer provides Go bindings for Android AChoreographer.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AChoreographer_refreshRateCallback

type AChoreographer_refreshRateCallback = capi.AChoreographer_refreshRateCallback

type AChoreographer_vsyncCallback

type AChoreographer_vsyncCallback = capi.AChoreographer_vsyncCallback

type AVsyncId

type AVsyncId = capi.AVsyncId

type Choreographer

type Choreographer struct {
	// contains filtered or unexported fields
}

Choreographer wraps the NDK AChoreographer handle.

func GetInstance

func GetInstance() *Choreographer

GetInstance calls the underlying C function.

func NewChoreographerFromPointer

func NewChoreographerFromPointer(ptr unsafe.Pointer) *Choreographer

NewChoreographerFromPointer wraps a raw AChoreographer pointer.

func NewChoreographerFromUintPtr added in v0.0.4

func NewChoreographerFromUintPtr(ptr uintptr) *Choreographer

NewChoreographerFromUintPtr wraps a uintptr as a Choreographer. The caller must ensure ptr points to a valid AChoreographer.

func (*Choreographer) Pointer

func (h *Choreographer) Pointer() unsafe.Pointer

Pointer returns the underlying pointer as unsafe.Pointer.

func (*Choreographer) UintPtr added in v0.0.4

func (h *Choreographer) UintPtr() uintptr

UintPtr returns the underlying pointer as a uintptr. This is useful for interop with gomobile bind, golang.org/x/mobile, gioui.org, and other packages that represent native handles as uintptr.

type ChoreographerFrameCallbackData

type ChoreographerFrameCallbackData struct {
	// contains filtered or unexported fields
}

ChoreographerFrameCallbackData wraps the NDK AChoreographerFrameCallbackData handle.

func NewChoreographerFrameCallbackDataFromPointer

func NewChoreographerFrameCallbackDataFromPointer(ptr unsafe.Pointer) *ChoreographerFrameCallbackData

NewChoreographerFrameCallbackDataFromPointer wraps a raw AChoreographerFrameCallbackData pointer.

func NewChoreographerFrameCallbackDataFromUintPtr added in v0.0.4

func NewChoreographerFrameCallbackDataFromUintPtr(ptr uintptr) *ChoreographerFrameCallbackData

NewChoreographerFrameCallbackDataFromUintPtr wraps a uintptr as a ChoreographerFrameCallbackData. The caller must ensure ptr points to a valid AChoreographerFrameCallbackData.

func (*ChoreographerFrameCallbackData) GetFrameTimeNanos

func (h *ChoreographerFrameCallbackData) GetFrameTimeNanos() int64

GetFrameTimeNanos returns the value directly.

func (*ChoreographerFrameCallbackData) GetFrameTimelineDeadlineNanos

func (h *ChoreographerFrameCallbackData) GetFrameTimelineDeadlineNanos(index uint64) int64

GetFrameTimelineDeadlineNanos returns the value directly.

func (*ChoreographerFrameCallbackData) GetFrameTimelineExpectedPresentationTimeNanos

func (h *ChoreographerFrameCallbackData) GetFrameTimelineExpectedPresentationTimeNanos(index uint64) int64

GetFrameTimelineExpectedPresentationTimeNanos returns the value directly.

func (*ChoreographerFrameCallbackData) GetFrameTimelinesLength

func (h *ChoreographerFrameCallbackData) GetFrameTimelinesLength() uint64

GetFrameTimelinesLength returns the value directly.

func (*ChoreographerFrameCallbackData) GetPreferredFrameTimelineIndex

func (h *ChoreographerFrameCallbackData) GetPreferredFrameTimelineIndex() uint64

GetPreferredFrameTimelineIndex returns the value directly.

func (*ChoreographerFrameCallbackData) Pointer

Pointer returns the underlying pointer as unsafe.Pointer.

func (*ChoreographerFrameCallbackData) UintPtr added in v0.0.4

UintPtr returns the underlying pointer as a uintptr. This is useful for interop with gomobile bind, golang.org/x/mobile, gioui.org, and other packages that represent native handles as uintptr.

type Error

type Error int32

Error represents an NDK error code.

func (Error) Error

func (e Error) Error() string

Jump to