Documentation
¶
Overview ¶
Package binderprocess provides access to ABinderProcess_* functions that are not part of the public NDK headers but available at runtime via dlsym in libbinder_ndk.so.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func StartThreadPool ¶
StartThreadPool starts the binder thread pool with the given number of threads. If threads is 0, the default thread count is used (only startThreadPool is called).
Types ¶
type ErrDLOpenLibbinderNDK ¶
type ErrDLOpenLibbinderNDK struct{}
ErrDLOpenLibbinderNDK is returned when libbinder_ndk.so cannot be loaded.
func (ErrDLOpenLibbinderNDK) Error ¶
func (ErrDLOpenLibbinderNDK) Error() string
type ErrSymbolSetThreadPoolMax ¶
type ErrSymbolSetThreadPoolMax struct{}
ErrSymbolSetThreadPoolMax is returned when ABinderProcess_setThreadPoolMaxThreadCount is not found.
func (ErrSymbolSetThreadPoolMax) Error ¶
func (ErrSymbolSetThreadPoolMax) Error() string
type ErrSymbolStartThreadPool ¶
type ErrSymbolStartThreadPool struct{}
ErrSymbolStartThreadPool is returned when ABinderProcess_startThreadPool is not found.
func (ErrSymbolStartThreadPool) Error ¶
func (ErrSymbolStartThreadPool) Error() string
Click to show internal directories.
Click to hide internal directories.