Documentation
¶
Overview ¶
Raw CGo bindings for Android configuration
Index ¶
- Constants
- func AConfiguration_copy(dest *AConfiguration, src *AConfiguration)
- func AConfiguration_delete(config *AConfiguration)
- func AConfiguration_diff(config1 *AConfiguration, config2 *AConfiguration) int32
- func AConfiguration_fromAssetManager(out *AConfiguration, am *AAssetManager)
- func AConfiguration_getCountry(config *AConfiguration, outCountry string)
- func AConfiguration_getDensity(config *AConfiguration) int32
- func AConfiguration_getGrammaticalGender(config *AConfiguration) int32
- func AConfiguration_getKeyboard(config *AConfiguration) int32
- func AConfiguration_getKeysHidden(config *AConfiguration) int32
- func AConfiguration_getLanguage(config *AConfiguration, outLanguage string)
- func AConfiguration_getLayoutDirection(config *AConfiguration) int32
- func AConfiguration_getMcc(config *AConfiguration) int32
- func AConfiguration_getMnc(config *AConfiguration) int32
- func AConfiguration_getNavHidden(config *AConfiguration) int32
- func AConfiguration_getNavigation(config *AConfiguration) int32
- func AConfiguration_getOrientation(config *AConfiguration) int32
- func AConfiguration_getScreenHeightDp(config *AConfiguration) int32
- func AConfiguration_getScreenLong(config *AConfiguration) int32
- func AConfiguration_getScreenRound(config *AConfiguration) int32
- func AConfiguration_getScreenSize(config *AConfiguration) int32
- func AConfiguration_getScreenWidthDp(config *AConfiguration) int32
- func AConfiguration_getSdkVersion(config *AConfiguration) int32
- func AConfiguration_getSmallestScreenWidthDp(config *AConfiguration) int32
- func AConfiguration_getTouchscreen(config *AConfiguration) int32
- func AConfiguration_getUiModeNight(config *AConfiguration) int32
- func AConfiguration_getUiModeType(config *AConfiguration) int32
- func AConfiguration_isBetterThan(base *AConfiguration, test *AConfiguration, requested *AConfiguration) int32
- func AConfiguration_match(base *AConfiguration, requested *AConfiguration) int32
- func AConfiguration_setCountry(config *AConfiguration, country string)
- func AConfiguration_setDensity(config *AConfiguration, density int32)
- func AConfiguration_setGrammaticalGender(config *AConfiguration, value int32)
- func AConfiguration_setKeyboard(config *AConfiguration, keyboard int32)
- func AConfiguration_setKeysHidden(config *AConfiguration, keysHidden int32)
- func AConfiguration_setLanguage(config *AConfiguration, language string)
- func AConfiguration_setLayoutDirection(config *AConfiguration, value int32)
- func AConfiguration_setMcc(config *AConfiguration, mcc int32)
- func AConfiguration_setMnc(config *AConfiguration, mnc int32)
- func AConfiguration_setNavHidden(config *AConfiguration, navHidden int32)
- func AConfiguration_setNavigation(config *AConfiguration, navigation int32)
- func AConfiguration_setOrientation(config *AConfiguration, orientation int32)
- func AConfiguration_setScreenHeightDp(config *AConfiguration, value int32)
- func AConfiguration_setScreenLong(config *AConfiguration, screenLong int32)
- func AConfiguration_setScreenSize(config *AConfiguration, screenSize int32)
- func AConfiguration_setScreenWidthDp(config *AConfiguration, value int32)
- func AConfiguration_setSdkVersion(config *AConfiguration, sdkVersion int32)
- func AConfiguration_setSmallestScreenWidthDp(config *AConfiguration, value int32)
- func AConfiguration_setTouchscreen(config *AConfiguration, touchscreen int32)
- func AConfiguration_setUiModeNight(config *AConfiguration, uiModeNight int32)
- func AConfiguration_setUiModeType(config *AConfiguration, uiModeType int32)
- type AAssetManager
- type AConfiguration
- type CgoAllocMap
- type SliceHeader
Constants ¶
const ( ACONFIGURATION_ORIENTATION_ANY = 0 ACONFIGURATION_ORIENTATION_PORT = 1 ACONFIGURATION_ORIENTATION_LAND = 2 ACONFIGURATION_ORIENTATION_SQUARE = 3 ACONFIGURATION_TOUCHSCREEN_ANY = 0 ACONFIGURATION_TOUCHSCREEN_NOTOUCH = 1 ACONFIGURATION_TOUCHSCREEN_STYLUS = 2 ACONFIGURATION_TOUCHSCREEN_FINGER = 3 ACONFIGURATION_DENSITY_DEFAULT = 0 ACONFIGURATION_DENSITY_LOW = 120 ACONFIGURATION_DENSITY_MEDIUM = 160 ACONFIGURATION_DENSITY_TV = 213 ACONFIGURATION_DENSITY_HIGH = 240 ACONFIGURATION_DENSITY_XHIGH = 320 ACONFIGURATION_DENSITY_XXHIGH = 480 ACONFIGURATION_DENSITY_XXXHIGH = 640 ACONFIGURATION_DENSITY_ANY = 65534 ACONFIGURATION_DENSITY_NONE = 65535 ACONFIGURATION_KEYBOARD_ANY = 0 ACONFIGURATION_KEYBOARD_NOKEYS = 1 ACONFIGURATION_KEYBOARD_QWERTY = 2 ACONFIGURATION_KEYBOARD_12KEY = 3 ACONFIGURATION_NAVIGATION_ANY = 0 ACONFIGURATION_NAVIGATION_NONAV = 1 ACONFIGURATION_NAVIGATION_DPAD = 2 ACONFIGURATION_NAVIGATION_TRACKBALL = 3 ACONFIGURATION_NAVIGATION_WHEEL = 4 ACONFIGURATION_KEYSHIDDEN_ANY = 0 ACONFIGURATION_KEYSHIDDEN_NO = 1 ACONFIGURATION_KEYSHIDDEN_YES = 2 ACONFIGURATION_KEYSHIDDEN_SOFT = 3 ACONFIGURATION_NAVHIDDEN_ANY = 0 ACONFIGURATION_NAVHIDDEN_NO = 1 ACONFIGURATION_NAVHIDDEN_YES = 2 ACONFIGURATION_SCREENSIZE_ANY = 0 ACONFIGURATION_SCREENSIZE_SMALL = 1 ACONFIGURATION_SCREENSIZE_NORMAL = 2 ACONFIGURATION_SCREENSIZE_LARGE = 3 ACONFIGURATION_SCREENSIZE_XLARGE = 4 ACONFIGURATION_SCREENLONG_ANY = 0 ACONFIGURATION_SCREENLONG_NO = 1 ACONFIGURATION_SCREENLONG_YES = 2 ACONFIGURATION_SCREENROUND_ANY = 0 ACONFIGURATION_SCREENROUND_NO = 1 ACONFIGURATION_SCREENROUND_YES = 2 ACONFIGURATION_WIDE_COLOR_GAMUT_ANY = 0 ACONFIGURATION_WIDE_COLOR_GAMUT_NO = 1 ACONFIGURATION_WIDE_COLOR_GAMUT_YES = 2 ACONFIGURATION_HDR_ANY = 0 ACONFIGURATION_HDR_NO = 1 ACONFIGURATION_HDR_YES = 2 ACONFIGURATION_UI_MODE_TYPE_ANY = 0 ACONFIGURATION_UI_MODE_TYPE_NORMAL = 1 ACONFIGURATION_UI_MODE_TYPE_DESK = 2 ACONFIGURATION_UI_MODE_TYPE_CAR = 3 ACONFIGURATION_UI_MODE_TYPE_TELEVISION = 4 ACONFIGURATION_UI_MODE_TYPE_APPLIANCE = 5 ACONFIGURATION_UI_MODE_TYPE_WATCH = 6 ACONFIGURATION_UI_MODE_TYPE_VR_HEADSET = 7 ACONFIGURATION_UI_MODE_NIGHT_ANY = 0 ACONFIGURATION_UI_MODE_NIGHT_NO = 1 ACONFIGURATION_UI_MODE_NIGHT_YES = 2 ACONFIGURATION_SCREEN_WIDTH_DP_ANY = 0 ACONFIGURATION_SCREEN_HEIGHT_DP_ANY = 0 ACONFIGURATION_SMALLEST_SCREEN_WIDTH_DP_ANY = 0 ACONFIGURATION_LAYOUTDIR_ANY = 0 ACONFIGURATION_LAYOUTDIR_LTR = 1 ACONFIGURATION_LAYOUTDIR_RTL = 2 ACONFIGURATION_MCC = 1 ACONFIGURATION_MNC = 2 ACONFIGURATION_LOCALE = 4 ACONFIGURATION_TOUCHSCREEN = 8 ACONFIGURATION_KEYBOARD = 16 ACONFIGURATION_KEYBOARD_HIDDEN = 32 ACONFIGURATION_NAVIGATION = 64 ACONFIGURATION_ORIENTATION = 128 ACONFIGURATION_DENSITY = 256 ACONFIGURATION_SCREEN_SIZE = 512 ACONFIGURATION_VERSION = 1024 ACONFIGURATION_SCREEN_LAYOUT = 2048 ACONFIGURATION_UI_MODE = 4096 ACONFIGURATION_SMALLEST_SCREEN_SIZE = 8192 ACONFIGURATION_LAYOUTDIR = 16384 ACONFIGURATION_SCREEN_ROUND = 32768 ACONFIGURATION_COLOR_MODE = 65536 ACONFIGURATION_GRAMMATICAL_GENDER = 131072 ACONFIGURATION_MNC_ZERO = 65535 ACONFIGURATION_GRAMMATICAL_GENDER_ANY = 0 ACONFIGURATION_GRAMMATICAL_GENDER_NEUTER = 1 ACONFIGURATION_GRAMMATICAL_GENDER_FEMININE = 2 ACONFIGURATION_GRAMMATICAL_GENDER_MASCULINE = 3 )
Variables ¶
This section is empty.
Functions ¶
func AConfiguration_copy ¶
func AConfiguration_copy(dest *AConfiguration, src *AConfiguration)
func AConfiguration_delete ¶
func AConfiguration_delete(config *AConfiguration)
func AConfiguration_diff ¶
func AConfiguration_diff(config1 *AConfiguration, config2 *AConfiguration) int32
func AConfiguration_fromAssetManager ¶
func AConfiguration_fromAssetManager(out *AConfiguration, am *AAssetManager)
func AConfiguration_getCountry ¶
func AConfiguration_getCountry(config *AConfiguration, outCountry string)
func AConfiguration_getDensity ¶
func AConfiguration_getDensity(config *AConfiguration) int32
func AConfiguration_getGrammaticalGender ¶
func AConfiguration_getGrammaticalGender(config *AConfiguration) int32
func AConfiguration_getKeyboard ¶
func AConfiguration_getKeyboard(config *AConfiguration) int32
func AConfiguration_getKeysHidden ¶
func AConfiguration_getKeysHidden(config *AConfiguration) int32
func AConfiguration_getLanguage ¶
func AConfiguration_getLanguage(config *AConfiguration, outLanguage string)
func AConfiguration_getLayoutDirection ¶
func AConfiguration_getLayoutDirection(config *AConfiguration) int32
func AConfiguration_getMcc ¶
func AConfiguration_getMcc(config *AConfiguration) int32
func AConfiguration_getMnc ¶
func AConfiguration_getMnc(config *AConfiguration) int32
func AConfiguration_getNavHidden ¶
func AConfiguration_getNavHidden(config *AConfiguration) int32
func AConfiguration_getNavigation ¶
func AConfiguration_getNavigation(config *AConfiguration) int32
func AConfiguration_getOrientation ¶
func AConfiguration_getOrientation(config *AConfiguration) int32
func AConfiguration_getScreenHeightDp ¶
func AConfiguration_getScreenHeightDp(config *AConfiguration) int32
func AConfiguration_getScreenLong ¶
func AConfiguration_getScreenLong(config *AConfiguration) int32
func AConfiguration_getScreenRound ¶
func AConfiguration_getScreenRound(config *AConfiguration) int32
func AConfiguration_getScreenSize ¶
func AConfiguration_getScreenSize(config *AConfiguration) int32
func AConfiguration_getScreenWidthDp ¶
func AConfiguration_getScreenWidthDp(config *AConfiguration) int32
func AConfiguration_getSdkVersion ¶
func AConfiguration_getSdkVersion(config *AConfiguration) int32
func AConfiguration_getSmallestScreenWidthDp ¶
func AConfiguration_getSmallestScreenWidthDp(config *AConfiguration) int32
func AConfiguration_getTouchscreen ¶
func AConfiguration_getTouchscreen(config *AConfiguration) int32
func AConfiguration_getUiModeNight ¶
func AConfiguration_getUiModeNight(config *AConfiguration) int32
func AConfiguration_getUiModeType ¶
func AConfiguration_getUiModeType(config *AConfiguration) int32
func AConfiguration_isBetterThan ¶
func AConfiguration_isBetterThan(base *AConfiguration, test *AConfiguration, requested *AConfiguration) int32
func AConfiguration_match ¶
func AConfiguration_match(base *AConfiguration, requested *AConfiguration) int32
func AConfiguration_setCountry ¶
func AConfiguration_setCountry(config *AConfiguration, country string)
func AConfiguration_setDensity ¶
func AConfiguration_setDensity(config *AConfiguration, density int32)
func AConfiguration_setGrammaticalGender ¶
func AConfiguration_setGrammaticalGender(config *AConfiguration, value int32)
func AConfiguration_setKeyboard ¶
func AConfiguration_setKeyboard(config *AConfiguration, keyboard int32)
func AConfiguration_setKeysHidden ¶
func AConfiguration_setKeysHidden(config *AConfiguration, keysHidden int32)
func AConfiguration_setLanguage ¶
func AConfiguration_setLanguage(config *AConfiguration, language string)
func AConfiguration_setLayoutDirection ¶
func AConfiguration_setLayoutDirection(config *AConfiguration, value int32)
func AConfiguration_setMcc ¶
func AConfiguration_setMcc(config *AConfiguration, mcc int32)
func AConfiguration_setMnc ¶
func AConfiguration_setMnc(config *AConfiguration, mnc int32)
func AConfiguration_setNavHidden ¶
func AConfiguration_setNavHidden(config *AConfiguration, navHidden int32)
func AConfiguration_setNavigation ¶
func AConfiguration_setNavigation(config *AConfiguration, navigation int32)
func AConfiguration_setOrientation ¶
func AConfiguration_setOrientation(config *AConfiguration, orientation int32)
func AConfiguration_setScreenHeightDp ¶
func AConfiguration_setScreenHeightDp(config *AConfiguration, value int32)
func AConfiguration_setScreenLong ¶
func AConfiguration_setScreenLong(config *AConfiguration, screenLong int32)
func AConfiguration_setScreenSize ¶
func AConfiguration_setScreenSize(config *AConfiguration, screenSize int32)
func AConfiguration_setScreenWidthDp ¶
func AConfiguration_setScreenWidthDp(config *AConfiguration, value int32)
func AConfiguration_setSdkVersion ¶
func AConfiguration_setSdkVersion(config *AConfiguration, sdkVersion int32)
func AConfiguration_setSmallestScreenWidthDp ¶
func AConfiguration_setSmallestScreenWidthDp(config *AConfiguration, value int32)
func AConfiguration_setTouchscreen ¶
func AConfiguration_setTouchscreen(config *AConfiguration, touchscreen int32)
func AConfiguration_setUiModeNight ¶
func AConfiguration_setUiModeNight(config *AConfiguration, uiModeNight int32)
func AConfiguration_setUiModeType ¶
func AConfiguration_setUiModeType(config *AConfiguration, uiModeType int32)
Types ¶
type AAssetManager ¶
type AAssetManager C.AAssetManager
type AConfiguration ¶
type AConfiguration C.AConfiguration
func AConfiguration_new ¶
func AConfiguration_new() *AConfiguration
type CgoAllocMap ¶
type CgoAllocMap struct {
// contains filtered or unexported fields
}
CgoAllocMap stores pointers to C allocated memory for future reference.
func UnpackPCharString ¶
func UnpackPCharString(str string) (*C.char, *CgoAllocMap)
UnpackPCharString copies the data from Go string as *C.char.
func (*CgoAllocMap) Add ¶
func (a *CgoAllocMap) Add(ptr unsafe.Pointer)
func (*CgoAllocMap) Borrow ¶
func (a *CgoAllocMap) Borrow(b *CgoAllocMap)
func (*CgoAllocMap) Free ¶
func (a *CgoAllocMap) Free()
func (*CgoAllocMap) IsEmpty ¶
func (a *CgoAllocMap) IsEmpty() bool
Click to show internal directories.
Click to hide internal directories.