Documentation
¶
Overview ¶
Raw CGo bindings for Android logging
Index ¶
- func Android_aborter_function6780BBF7(cabort_message *C.char)
- func Android_log_buf_write(bufID int32, prio int32, tag string, text string) int32
- func Android_log_call_aborter(abort_message string)
- func Android_log_default_aborter(abort_message string)
- func Android_log_get_minimum_priority() int32
- func Android_log_id_is_valid(id Log_id_t) bool
- func Android_log_is_loggable(prio int32, tag string, default_prio int32) int32
- func Android_log_is_loggable_len(prio int32, tag string, len uint64, default_prio int32) int32
- func Android_log_logd_logger(log_message *Android_log_message)
- func Android_log_set_aborter(aborter Android_aborter_function)
- func Android_log_set_default_tag(tag string)
- func Android_log_set_logger(logger Android_logger_function)
- func Android_log_set_minimum_priority(priority int32) int32
- func Android_log_stderr_logger(log_message *Android_log_message)
- func Android_log_write(prio int32, tag string, text string) int32
- func Android_log_write_log_message(log_message *Android_log_message)
- func Android_logger_functionCB93890B(clog_message *C.struct___android_log_message)
- type Android_LogPriority
- type Android_aborter_function
- type Android_log_message
- type Android_logger_function
- type CgoAllocMap
- type Log_id_t
- type SliceHeader
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Android_log_buf_write ¶
func Android_log_call_aborter ¶
func Android_log_call_aborter(abort_message string)
func Android_log_default_aborter ¶
func Android_log_default_aborter(abort_message string)
func Android_log_get_minimum_priority ¶
func Android_log_get_minimum_priority() int32
func Android_log_id_is_valid ¶
func Android_log_is_loggable ¶
func Android_log_logd_logger ¶
func Android_log_logd_logger(log_message *Android_log_message)
func Android_log_set_aborter ¶
func Android_log_set_aborter(aborter Android_aborter_function)
func Android_log_set_default_tag ¶
func Android_log_set_default_tag(tag string)
func Android_log_set_logger ¶
func Android_log_set_logger(logger Android_logger_function)
func Android_log_stderr_logger ¶
func Android_log_stderr_logger(log_message *Android_log_message)
func Android_log_write_log_message ¶
func Android_log_write_log_message(log_message *Android_log_message)
func Android_logger_functionCB93890B ¶
func Android_logger_functionCB93890B(clog_message *C.struct___android_log_message)
Types ¶
type Android_LogPriority ¶
type Android_LogPriority int32
const ( ANDROID_LOG_UNKNOWN Android_LogPriority = 0 ANDROID_LOG_DEFAULT Android_LogPriority = 1 ANDROID_LOG_VERBOSE Android_LogPriority = 2 ANDROID_LOG_DEBUG Android_LogPriority = 3 ANDROID_LOG_INFO Android_LogPriority = 4 ANDROID_LOG_WARN Android_LogPriority = 5 ANDROID_LOG_ERROR Android_LogPriority = 6 ANDROID_LOG_FATAL Android_LogPriority = 7 ANDROID_LOG_SILENT Android_LogPriority = 8 )
type Android_aborter_function ¶
type Android_aborter_function func(abort_message string)
func NewAndroid_aborter_functionRef ¶
func NewAndroid_aborter_functionRef(ref unsafe.Pointer) *Android_aborter_function
func (Android_aborter_function) PassRef ¶
func (x Android_aborter_function) PassRef() (ref *C.__android_aborter_function, allocs *CgoAllocMap)
func (Android_aborter_function) PassValue ¶
func (x Android_aborter_function) PassValue() (ref C.__android_aborter_function, allocs *CgoAllocMap)
type Android_log_message ¶
type Android_log_message C.struct___android_log_message
type Android_logger_function ¶
type Android_logger_function func(log_message *Android_log_message)
func NewAndroid_logger_functionRef ¶
func NewAndroid_logger_functionRef(ref unsafe.Pointer) *Android_logger_function
func (Android_logger_function) PassRef ¶
func (x Android_logger_function) PassRef() (ref *C.__android_logger_function, allocs *CgoAllocMap)
func (Android_logger_function) PassValue ¶
func (x Android_logger_function) PassValue() (ref C.__android_logger_function, allocs *CgoAllocMap)
type CgoAllocMap ¶
type CgoAllocMap struct {
// contains filtered or unexported fields
}
CgoAllocMap stores pointers to C allocated memory for future reference.
func UnpackPCharString ¶
func UnpackPCharString(str string) (*C.char, *CgoAllocMap)
UnpackPCharString copies the data from Go string as *C.char.
func (*CgoAllocMap) Add ¶
func (a *CgoAllocMap) Add(ptr unsafe.Pointer)
func (*CgoAllocMap) Borrow ¶
func (a *CgoAllocMap) Borrow(b *CgoAllocMap)
func (*CgoAllocMap) Free ¶
func (a *CgoAllocMap) Free()
func (*CgoAllocMap) IsEmpty ¶
func (a *CgoAllocMap) IsEmpty() bool
type Log_id_t ¶
type Log_id_t int32
const ( LOG_ID_MIN Log_id_t = 0 LOG_ID_MAIN Log_id_t = 0 LOG_ID_RADIO Log_id_t = 1 LOG_ID_EVENTS Log_id_t = 2 LOG_ID_SYSTEM Log_id_t = 3 LOG_ID_CRASH Log_id_t = 4 LOG_ID_STATS Log_id_t = 5 LOG_ID_SECURITY Log_id_t = 6 LOG_ID_KERNEL Log_id_t = 7 LOG_ID_MAX Log_id_t = 8 LOG_ID_DEFAULT Log_id_t = 2147483647 )
Click to show internal directories.
Click to hide internal directories.