Documentation
¶
Overview ¶
Raw CGo bindings for Android Permission Manager
Index ¶
Constants ¶
const ( PERMISSION_MANAGER_PERMISSION_GRANTED = 0 PERMISSION_MANAGER_PERMISSION_DENIED = -1 )
const ( PERMISSION_MANAGER_STATUS_OK = 0 PERMISSION_MANAGER_STATUS_ERROR_UNKNOWN = -1 PERMISSION_MANAGER_STATUS_SERVICE_UNAVAILABLE = -2 )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CgoAllocMap ¶
type CgoAllocMap struct {
// contains filtered or unexported fields
}
CgoAllocMap stores pointers to C allocated memory for future reference.
func UnpackPCharString ¶
func UnpackPCharString(str string) (*C.char, *CgoAllocMap)
UnpackPCharString copies the data from Go string as *C.char.
func (*CgoAllocMap) Add ¶
func (a *CgoAllocMap) Add(ptr unsafe.Pointer)
func (*CgoAllocMap) Borrow ¶
func (a *CgoAllocMap) Borrow(b *CgoAllocMap)
func (*CgoAllocMap) Free ¶
func (a *CgoAllocMap) Free()
func (*CgoAllocMap) IsEmpty ¶
func (a *CgoAllocMap) IsEmpty() bool
Click to show internal directories.
Click to hide internal directories.