Documentation
¶
Overview ¶
Raw CGo bindings for Android Shared Memory
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ASharedMemory_create ¶
func ASharedMemory_getSize ¶
func ASharedMemory_setProt ¶
Types ¶
type CgoAllocMap ¶
type CgoAllocMap struct {
// contains filtered or unexported fields
}
CgoAllocMap stores pointers to C allocated memory for future reference.
func UnpackPCharString ¶
func UnpackPCharString(str string) (*C.char, *CgoAllocMap)
UnpackPCharString copies the data from Go string as *C.char.
func (*CgoAllocMap) Add ¶
func (a *CgoAllocMap) Add(ptr unsafe.Pointer)
func (*CgoAllocMap) Borrow ¶
func (a *CgoAllocMap) Borrow(b *CgoAllocMap)
func (*CgoAllocMap) Free ¶
func (a *CgoAllocMap) Free()
func (*CgoAllocMap) IsEmpty ¶
func (a *CgoAllocMap) IsEmpty() bool
Click to show internal directories.
Click to hide internal directories.