storage

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 16, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Raw CGo bindings for Android Storage Manager

Index

Constants

const (
	AOBB_STATE_MOUNTED                 = 1
	AOBB_STATE_UNMOUNTED               = 2
	AOBB_STATE_ERROR_INTERNAL          = 20
	AOBB_STATE_ERROR_COULD_NOT_MOUNT   = 21
	AOBB_STATE_ERROR_COULD_NOT_UNMOUNT = 22
	AOBB_STATE_ERROR_NOT_MOUNTED       = 23
	AOBB_STATE_ERROR_ALREADY_MOUNTED   = 24
	AOBB_STATE_ERROR_PERMISSION_DENIED = 25
)

Variables

This section is empty.

Functions

func AStorageManager_delete

func AStorageManager_delete(mgr *AStorageManager)

func AStorageManager_getMountedObbPath

func AStorageManager_getMountedObbPath(mgr *AStorageManager, filename string) string

func AStorageManager_isObbMounted

func AStorageManager_isObbMounted(mgr *AStorageManager, filename string) int32

func AStorageManager_mountObb

func AStorageManager_mountObb(mgr *AStorageManager, filename string, key string, cb AStorageManager_obbCallbackFunc, data unsafe.Pointer)

func AStorageManager_obbCallbackFuncA6785822

func AStorageManager_obbCallbackFuncA6785822(cfilename *C.char, cstate C.int, cdata unsafe.Pointer)

func AStorageManager_unmountObb

func AStorageManager_unmountObb(mgr *AStorageManager, filename string, force int32, cb AStorageManager_obbCallbackFunc, data unsafe.Pointer)

Types

type AStorageManager

type AStorageManager C.AStorageManager

func AStorageManager_new

func AStorageManager_new() *AStorageManager

type AStorageManager_obbCallbackFunc

type AStorageManager_obbCallbackFunc func(filename string, state int32, data unsafe.Pointer)

func NewAStorageManager_obbCallbackFuncRef

func NewAStorageManager_obbCallbackFuncRef(ref unsafe.Pointer) *AStorageManager_obbCallbackFunc

func (AStorageManager_obbCallbackFunc) PassRef

func (AStorageManager_obbCallbackFunc) PassValue

type CgoAllocMap

type CgoAllocMap struct {
	// contains filtered or unexported fields
}

CgoAllocMap stores pointers to C allocated memory for future reference.

func UnpackPCharString

func UnpackPCharString(str string) (*C.char, *CgoAllocMap)

UnpackPCharString copies the data from Go string as *C.char.

func (*CgoAllocMap) Add

func (a *CgoAllocMap) Add(ptr unsafe.Pointer)

func (*CgoAllocMap) Borrow

func (a *CgoAllocMap) Borrow(b *CgoAllocMap)

func (*CgoAllocMap) Free

func (a *CgoAllocMap) Free()

func (*CgoAllocMap) IsEmpty

func (a *CgoAllocMap) IsEmpty() bool

type SliceHeader

type SliceHeader struct {
	Data unsafe.Pointer
	Len  int
	Cap  int
}

Jump to