Documentation
¶
Overview ¶
Raw CGo bindings for Android Sync
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Sync_file_info_free ¶
func Sync_file_info_free(info *Sync_file_info_s)
Types ¶
type CgoAllocMap ¶
type CgoAllocMap struct {
// contains filtered or unexported fields
}
CgoAllocMap stores pointers to C allocated memory for future reference.
func UnpackPCharString ¶
func UnpackPCharString(str string) (*C.char, *CgoAllocMap)
UnpackPCharString copies the data from Go string as *C.char.
func (*CgoAllocMap) Add ¶
func (a *CgoAllocMap) Add(ptr unsafe.Pointer)
func (*CgoAllocMap) Borrow ¶
func (a *CgoAllocMap) Borrow(b *CgoAllocMap)
func (*CgoAllocMap) Free ¶
func (a *CgoAllocMap) Free()
func (*CgoAllocMap) IsEmpty ¶
func (a *CgoAllocMap) IsEmpty() bool
type Sync_file_info_s ¶
type Sync_file_info_s C.struct_sync_file_info
func Sync_file_info ¶
func Sync_file_info(fd int32) *Sync_file_info_s
Click to show internal directories.
Click to hide internal directories.