Documentation
¶
Overview ¶
Package choreographer provides Go bindings for Android AChoreographer.
Index ¶
- type AChoreographer_refreshRateCallback
- type AChoreographer_vsyncCallback
- type AVsyncId
- type Choreographer
- type ChoreographerFrameCallbackData
- func (h *ChoreographerFrameCallbackData) GetFrameTimeNanos() int64
- func (h *ChoreographerFrameCallbackData) GetFrameTimelineDeadlineNanos(index uint64) int64
- func (h *ChoreographerFrameCallbackData) GetFrameTimelineExpectedPresentationTimeNanos(index uint64) int64
- func (h *ChoreographerFrameCallbackData) GetFrameTimelinesLength() uint64
- func (h *ChoreographerFrameCallbackData) GetPreferredFrameTimelineIndex() uint64
- func (h *ChoreographerFrameCallbackData) Pointer() unsafe.Pointer
- func (h *ChoreographerFrameCallbackData) UintPtr() uintptr
- type Error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AChoreographer_refreshRateCallback ¶
type AChoreographer_refreshRateCallback = capi.AChoreographer_refreshRateCallback
type AChoreographer_vsyncCallback ¶
type AChoreographer_vsyncCallback = capi.AChoreographer_vsyncCallback
type Choreographer ¶
type Choreographer struct {
// contains filtered or unexported fields
}
Choreographer wraps the NDK AChoreographer handle.
func NewChoreographerFromPointer ¶
func NewChoreographerFromPointer(ptr unsafe.Pointer) *Choreographer
NewChoreographerFromPointer wraps a raw AChoreographer pointer.
func NewChoreographerFromUintPtr ¶ added in v0.0.4
func NewChoreographerFromUintPtr(ptr uintptr) *Choreographer
NewChoreographerFromUintPtr wraps a uintptr as a Choreographer. The caller must ensure ptr points to a valid AChoreographer.
func (*Choreographer) Pointer ¶
func (h *Choreographer) Pointer() unsafe.Pointer
Pointer returns the underlying pointer as unsafe.Pointer.
func (*Choreographer) UintPtr ¶ added in v0.0.4
func (h *Choreographer) UintPtr() uintptr
UintPtr returns the underlying pointer as a uintptr. This is useful for interop with gomobile bind, golang.org/x/mobile, gioui.org, and other packages that represent native handles as uintptr.
type ChoreographerFrameCallbackData ¶
type ChoreographerFrameCallbackData struct {
// contains filtered or unexported fields
}
ChoreographerFrameCallbackData wraps the NDK AChoreographerFrameCallbackData handle.
func NewChoreographerFrameCallbackDataFromPointer ¶
func NewChoreographerFrameCallbackDataFromPointer(ptr unsafe.Pointer) *ChoreographerFrameCallbackData
NewChoreographerFrameCallbackDataFromPointer wraps a raw AChoreographerFrameCallbackData pointer.
func NewChoreographerFrameCallbackDataFromUintPtr ¶ added in v0.0.4
func NewChoreographerFrameCallbackDataFromUintPtr(ptr uintptr) *ChoreographerFrameCallbackData
NewChoreographerFrameCallbackDataFromUintPtr wraps a uintptr as a ChoreographerFrameCallbackData. The caller must ensure ptr points to a valid AChoreographerFrameCallbackData.
func (*ChoreographerFrameCallbackData) GetFrameTimeNanos ¶
func (h *ChoreographerFrameCallbackData) GetFrameTimeNanos() int64
GetFrameTimeNanos returns the value directly.
func (*ChoreographerFrameCallbackData) GetFrameTimelineDeadlineNanos ¶
func (h *ChoreographerFrameCallbackData) GetFrameTimelineDeadlineNanos(index uint64) int64
GetFrameTimelineDeadlineNanos returns the value directly.
func (*ChoreographerFrameCallbackData) GetFrameTimelineExpectedPresentationTimeNanos ¶
func (h *ChoreographerFrameCallbackData) GetFrameTimelineExpectedPresentationTimeNanos(index uint64) int64
GetFrameTimelineExpectedPresentationTimeNanos returns the value directly.
func (*ChoreographerFrameCallbackData) GetFrameTimelinesLength ¶
func (h *ChoreographerFrameCallbackData) GetFrameTimelinesLength() uint64
GetFrameTimelinesLength returns the value directly.
func (*ChoreographerFrameCallbackData) GetPreferredFrameTimelineIndex ¶
func (h *ChoreographerFrameCallbackData) GetPreferredFrameTimelineIndex() uint64
GetPreferredFrameTimelineIndex returns the value directly.
func (*ChoreographerFrameCallbackData) Pointer ¶
func (h *ChoreographerFrameCallbackData) Pointer() unsafe.Pointer
Pointer returns the underlying pointer as unsafe.Pointer.
func (*ChoreographerFrameCallbackData) UintPtr ¶ added in v0.0.4
func (h *ChoreographerFrameCallbackData) UintPtr() uintptr
UintPtr returns the underlying pointer as a uintptr. This is useful for interop with gomobile bind, golang.org/x/mobile, gioui.org, and other packages that represent native handles as uintptr.